@@ -391,7 +391,7 @@ OC.L10N.register(
     "From" : "No",
     "To" : "Līdz",
     "Calendar" : "Kalendārs",
-    "Attendees" : "Apmeklētāji",
+    "Attendees" : "Dalībnieki",
     "Save" : "Saglabāt",
     "No results" : "Nav iznākuma",
     "Done" : "Pabeigts",
@@ -408,7 +408,7 @@ OC.L10N.register(
     "Collapse" : "Sakļaut",
     "Favorite" : "Izlasē",
     "Date:" : "Datums:",
-    "Hide details" : "Slēpt detaļas",
+    "Hide details" : "Paslēpt informāciju",
     "Show details" : "Rādīt informāciju",
     "Disable" : "Deaktivēt",
     "Enable" : "Iespējot",
@@ -467,12 +467,12 @@ OC.L10N.register(
     "Remove participant" : "Noņemt dalībnieku",
     "Demote from moderator" : "Pazemināt no regulētāja",
     "Promote to moderator" : "Paaugstināt par regulētāju",
-    "Remove" : "Izņemt",
+    "Remove" : "Noņemt",
     "Add users or groups" : "Add users or groups",
     "Searching …" : "Meklē...",
     "Participants" : "Dalībnieki",
     "Chat" : "Tērzēt",
-    "Details" : "Detaļas",
+    "Details" : "Informācija",
     "From User" : "No lietotāja",
     "Load more results" : "Ielādēt vairāk iznākumu",
     "Projects" : "Projekti",
